pub fn pretty_comments(
module: &Mod,
comment_ranges: &CommentRanges,
source: &str,
) -> StringExpand description
Public function for generating a printable string of the debug comments.
pub fn pretty_comments(
module: &Mod,
comment_ranges: &CommentRanges,
source: &str,
) -> StringPublic function for generating a printable string of the debug comments.